@@ -12,9 +12,7 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
-#include "bitmap.h"
 #include "color.h"
-#include "colormap.h"
 #include "cursor.h"
 #include "device.h"
 #include "devicemanager.h"
@@ -28,7 +26,6 @@
 #include "pixbufanimationiter.h"
 #include "pixbufformat.h"
 #include "pixbufloader.h"
-#include "pixmap.h"
 #include "rectangle.h"
 #include "screen.h"
 #include "types.h"
@@ -40,7 +37,6 @@ extern "C"
 
 //Declarations of the *_get_type() functions:
 
-GType gdk_colormap_get_type(void);
 GType gdk_device_get_type(void);
 GType gdk_device_manager_get_type(void);
 GType gdk_display_get_type(void);
@@ -51,7 +47,6 @@ GType gdk_pixbuf_get_type(void);
 GType gdk_pixbuf_animation_get_type(void);
 GType gdk_pixbuf_animation_iter_get_type(void);
 GType gdk_pixbuf_loader_get_type(void);
-GType gdk_pixmap_get_type(void);
 GType gdk_screen_get_type(void);
 GType gdk_visual_get_type(void);
 GType gdk_window_object_get_type(void);
@@ -64,7 +59,6 @@ GQuark gdk_pixbuf_error_quark(void);
 
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
-namespace Gdk {  class Colormap_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gdk {  class Device_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gdk {  class DeviceManager_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gdk {  class Display_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -75,7 +69,6 @@ namespace Gdk {  class Pixbuf_Class { public: static Glib::ObjectBase* wrap_new(
 namespace Gdk {  class PixbufAnimation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gdk {  class PixbufAnimationIter_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gdk {  class PixbufLoader_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gdk {  class Pixmap_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gdk {  class Screen_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gdk {  class Visual_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gdk {  class Window_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -88,7 +81,6 @@ void wrap_init()
   Glib::Error::register_domain(gdk_pixbuf_error_quark(), &Gdk::PixbufError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
-  Glib::wrap_register(gdk_colormap_get_type(), &Gdk::Colormap_Class::wrap_new);
   Glib::wrap_register(gdk_device_get_type(), &Gdk::Device_Class::wrap_new);
   Glib::wrap_register(gdk_device_manager_get_type(), &Gdk::DeviceManager_Class::wrap_new);
   Glib::wrap_register(gdk_display_get_type(), &Gdk::Display_Class::wrap_new);
@@ -99,13 +91,11 @@ void wrap_init()
   Glib::wrap_register(gdk_pixbuf_animation_get_type(), &Gdk::PixbufAnimation_Class::wrap_new);
   Glib::wrap_register(gdk_pixbuf_animation_iter_get_type(), &Gdk::PixbufAnimationIter_Class::wrap_new);
   Glib::wrap_register(gdk_pixbuf_loader_get_type(), &Gdk::PixbufLoader_Class::wrap_new);
-  Glib::wrap_register(gdk_pixmap_get_type(), &Gdk::Pixmap_Class::wrap_new);
   Glib::wrap_register(gdk_screen_get_type(), &Gdk::Screen_Class::wrap_new);
   Glib::wrap_register(gdk_visual_get_type(), &Gdk::Visual_Class::wrap_new);
   Glib::wrap_register(gdk_window_object_get_type(), &Gdk::Window_Class::wrap_new);
 
   // Register the gtkmm gtypes:
-  Gdk::Colormap::get_type();
   Gdk::Device::get_type();
   Gdk::DeviceManager::get_type();
   Gdk::Display::get_type();
@@ -116,7 +106,6 @@ void wrap_init()
   Gdk::PixbufAnimation::get_type();
   Gdk::PixbufAnimationIter::get_type();
   Gdk::PixbufLoader::get_type();
-  Gdk::Pixmap::get_type();
   Gdk::Screen::get_type();
   Gdk::Visual::get_type();
   Gdk::Window::get_type();
