@@ -36,8 +36,7 @@ int main(int argc, char** argv)
 {
   gtk_init(&argc, &argv);
 
-  std::cout << get_defs( GDK_TYPE_COLORMAP )
-            << get_defs( GDK_TYPE_DRAG_CONTEXT )
+  std::cout << get_defs( GDK_TYPE_DRAG_CONTEXT )
             << get_defs( GDK_TYPE_DISPLAY )
 #if !defined(G_OS_WIN32)
             << get_defs( GDK_TYPE_DISPLAY_MANAGER )
@@ -46,7 +45,6 @@ int main(int argc, char** argv)
             << get_defs( GDK_TYPE_PIXBUF )
             << get_defs( GDK_TYPE_PIXBUF_ANIMATION )
             << get_defs( GDK_TYPE_PIXBUF_LOADER )
-            << get_defs( GDK_TYPE_PIXMAP )
             << get_defs( GDK_TYPE_SCREEN )
             << get_defs( GDK_TYPE_VISUAL )
             << get_defs( GDK_TYPE_WINDOW )
@@ -71,6 +69,7 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_CALENDAR )
             << get_defs( GTK_TYPE_CHECK_BUTTON )
             << get_defs( GTK_TYPE_CHECK_MENU_ITEM )
+            << get_defs( GTK_TYPE_CELL_EDITABLE )
             << get_defs( GTK_TYPE_CELL_LAYOUT )
             << get_defs( GTK_TYPE_CELL_RENDERER )
             << get_defs( GTK_TYPE_CELL_RENDERER_ACCEL )
@@ -85,7 +84,9 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_CLIPBOARD )
             << get_defs( GTK_TYPE_COLOR_BUTTON )
             << get_defs( GTK_TYPE_COLOR_SELECTION )
+            << get_defs( GTK_TYPE_COLOR_SELECTION_DIALOG )
             << get_defs( GTK_TYPE_COMBO_BOX )
+            << get_defs( GTK_TYPE_COMBO_BOX_ENTRY )
             << get_defs( GTK_TYPE_CONTAINER )
             << get_defs( GTK_TYPE_CELL_VIEW )
             << get_defs( GTK_TYPE_DIALOG )
@@ -97,6 +98,7 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_EVENT_BOX )
             << get_defs( GTK_TYPE_EXPANDER )
             << get_defs( GTK_TYPE_FILE_FILTER )
+            << get_defs( GTK_TYPE_FILE_CHOOSER )
             << get_defs( GTK_TYPE_FILE_CHOOSER_BUTTON )
             << get_defs( GTK_TYPE_FILE_CHOOSER_DIALOG )
             << get_defs( GTK_TYPE_FILE_CHOOSER_WIDGET )
@@ -123,7 +125,6 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_MESSAGE_DIALOG )
             << get_defs( GTK_TYPE_MISC )
             << get_defs( GTK_TYPE_NOTEBOOK )
-            << get_defs( GTK_TYPE_OBJECT )
             << get_defs( GTK_TYPE_OFFSCREEN_WINDOW )
             << get_defs( GTK_TYPE_ORIENTABLE )
             << get_defs( GTK_TYPE_PANED )
@@ -138,6 +139,8 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_PAGE_SETUP_UNIX_DIALOG )
             << get_defs( GTK_TYPE_PRINT_UNIX_DIALOG )
 #endif /* G_OS_WIN32 */
+            << get_defs( GTK_TYPE_PRINT_SETTINGS )
+            << get_defs( GTK_TYPE_PRINT_OPERATION_PREVIEW )
             << get_defs( GTK_TYPE_PROGRESS_BAR )
             << get_defs( GTK_TYPE_RADIO_BUTTON )
             << get_defs( GTK_TYPE_RADIO_TOOL_BUTTON )
@@ -159,7 +162,6 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_SEPARATOR_TOOL_ITEM )
             << get_defs( GTK_TYPE_SETTINGS )
             << get_defs( GTK_TYPE_SIZE_GROUP )
-            << get_defs( GTK_TYPE_SIZE_REQUEST )
 #if !defined(G_OS_WIN32)
             << get_defs( GTK_TYPE_SOCKET )
 #endif /* G_OS_WIN32 */
@@ -186,7 +188,10 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_TOOLTIP )
             << get_defs( GTK_TYPE_TREE_SELECTION )
             << get_defs( GTK_TYPE_TREE_MODEL )
+            << get_defs( GTK_TYPE_TREE_SELECTION )
+            << get_defs( GTK_TYPE_TREE_SORTABLE )
             << get_defs( GTK_TYPE_TREE_MODEL_FILTER )
+            << get_defs( GTK_TYPE_TREE_MODEL_SORT )
             << get_defs( GTK_TYPE_TREE_STORE )
             << get_defs( GTK_TYPE_TREE_VIEW )
             << get_defs( GTK_TYPE_TREE_VIEW_COLUMN )
